sshcert

package
v0.0.0-...-c2bd7a8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 17, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

The sshcert package provides a convenient function for parsing a SSH certificate.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ParseCert

func ParseCert(certBytes []byte) (*ssh.Certificate, error)

ParseCert will parse the provided byte slice (in OpenSSH certficate format) and return a *ssh.Certificate.

Any parsing errors will result in a nil *ssh.Certificate returned along with the error.

Types

This section is empty.

Jump to