Documentation
¶
Overview ¶
The sshcert package provides a convenient function for parsing a SSH certificate.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ParseCert ¶
func ParseCert(certBytes []byte) (*ssh.Certificate, error)
ParseCert will parse the provided byte slice (in OpenSSH certficate format) and return a *ssh.Certificate.
Any parsing errors will result in a nil *ssh.Certificate returned along with the error.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.